这是一个专门从文本里面提取中国的省，市，县的一个python模块
=======================================================
例子：
```python
from get_province_city_county import get_city
citys=get_city("我出生在一个名字叫安徽的省份，我去过浙江，江苏，合肥还有淮南，但我最喜欢的还是合肥，因为我在蜀山区生活过一段时间")
print(citys)
```
结果:('安徽省', 5, '合肥市', 3, '蜀山区', 1)

你也可以通过h_zd参数来指定要提取的省市范围，将提取范围缩小，以便得到更精确的结果

例子:
```python
from get_province_city_county import get_city
citys=get_city("我出生在一个名字叫安徽的省份，我去过浙江，江苏，台州，合肥还有淮南，但我最喜欢的还是合肥，因为我在蜀山区生活过一段时间",h_zd="浙江")
print(citys)
```
结果:

('浙江省', 3, '台州市', 1, '', 0)

通过h_zd这个参数，就可以锁定范围了